==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkChacoReader.java <==
// java wrapper for vtkChacoReader object
//

package vtk;
import vtk.*;

public class vtkChacoReader extends vtkUnstructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBaseName_2(String id0);
  public void SetBaseName(String id0)
    { SetBaseName_2(id0); }

  private native String GetBaseName_3();
  public String GetBaseName()
    { return GetBaseName_3(); }

  private native void SetGenerateGlobalElementIdArray_4(int id0);
  public void SetGenerateGlobalElementIdArray(int id0)
    { SetGenerateGlobalElementIdArray_4(id0); }

  private native int GetGenerateGlobalElementIdArray_5();
  public int GetGenerateGlobalElementIdArray()
    { return GetGenerateGlobalElementIdArray_5(); }

  private native void GenerateGlobalElementIdArrayOn_6();
  public void GenerateGlobalElementIdArrayOn()
    { GenerateGlobalElementIdArrayOn_6(); }

  private native void GenerateGlobalElementIdArrayOff_7();
  public void GenerateGlobalElementIdArrayOff()
    { GenerateGlobalElementIdArrayOff_7(); }

  private native String GetGlobalElementIdArrayName_8();
  public String GetGlobalElementIdArrayName()
    { return GetGlobalElementIdArrayName_8(); }

  private native void SetGenerateGlobalNodeIdArray_9(int id0);
  public void SetGenerateGlobalNodeIdArray(int id0)
    { SetGenerateGlobalNodeIdArray_9(id0); }

  private native int GetGenerateGlobalNodeIdArray_10();
  public int GetGenerateGlobalNodeIdArray()
    { return GetGenerateGlobalNodeIdArray_10(); }

  private native void GenerateGlobalNodeIdArrayOn_11();
  public void GenerateGlobalNodeIdArrayOn()
    { GenerateGlobalNodeIdArrayOn_11(); }

  private native void GenerateGlobalNodeIdArrayOff_12();
  public void GenerateGlobalNodeIdArrayOff()
    { GenerateGlobalNodeIdArrayOff_12(); }

  private native String GetGlobalNodeIdArrayName_13();
  public String GetGlobalNodeIdArrayName()
    { return GetGlobalNodeIdArrayName_13(); }

  private native void SetGenerateVertexWeightArrays_14(int id0);
  public void SetGenerateVertexWeightArrays(int id0)
    { SetGenerateVertexWeightArrays_14(id0); }

  private native int GetGenerateVertexWeightArrays_15();
  public int GetGenerateVertexWeightArrays()
    { return GetGenerateVertexWeightArrays_15(); }

  private native void GenerateVertexWeightArraysOn_16();
  public void GenerateVertexWeightArraysOn()
    { GenerateVertexWeightArraysOn_16(); }

  private native void GenerateVertexWeightArraysOff_17();
  public void GenerateVertexWeightArraysOff()
    { GenerateVertexWeightArraysOff_17(); }

  private native int GetNumberOfVertexWeights_18();
  public int GetNumberOfVertexWeights()
    { return GetNumberOfVertexWeights_18(); }

  private native String GetVertexWeightArrayName_19(int id0);
  public String GetVertexWeightArrayName(int id0)
    { return GetVertexWeightArrayName_19(id0); }

  private native void SetGenerateEdgeWeightArrays_20(int id0);
  public void SetGenerateEdgeWeightArrays(int id0)
    { SetGenerateEdgeWeightArrays_20(id0); }

  private native int GetGenerateEdgeWeightArrays_21();
  public int GetGenerateEdgeWeightArrays()
    { return GetGenerateEdgeWeightArrays_21(); }

  private native void GenerateEdgeWeightArraysOn_22();
  public void GenerateEdgeWeightArraysOn()
    { GenerateEdgeWeightArraysOn_22(); }

  private native void GenerateEdgeWeightArraysOff_23();
  public void GenerateEdgeWeightArraysOff()
    { GenerateEdgeWeightArraysOff_23(); }

  private native int GetNumberOfEdgeWeights_24();
  public int GetNumberOfEdgeWeights()
    { return GetNumberOfEdgeWeights_24(); }

  private native String GetEdgeWeightArrayName_25(int id0);
  public String GetEdgeWeightArrayName(int id0)
    { return GetEdgeWeightArrayName_25(id0); }

  private native int GetDimensionality_26();
  public int GetDimensionality()
    { return GetDimensionality_26(); }

  private native int GetNumberOfEdges_27();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_27(); }

  private native int GetNumberOfVertices_28();
  public int GetNumberOfVertices()
    { return GetNumberOfVertices_28(); }

  private native int GetNumberOfCellWeightArrays_29();
  public int GetNumberOfCellWeightArrays()
    { return GetNumberOfCellWeightArrays_29(); }

  private native int GetNumberOfPointWeightArrays_30();
  public int GetNumberOfPointWeightArrays()
    { return GetNumberOfPointWeightArrays_30(); }

  public vtkChacoReader() { super(); }

  public vtkChacoReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkChacoReader.java <==
// java wrapper for vtkChacoReader object
//

package vtk;
import vtk.*;

public class vtkChacoReader extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBaseName_2(String id0);
  public void SetBaseName(String id0)
    { SetBaseName_2(id0); }

  private native String GetBaseName_3();
  public String GetBaseName()
    { return GetBaseName_3(); }

  private native void SetGenerateGlobalElementIdArray_4(int id0);
  public void SetGenerateGlobalElementIdArray(int id0)
    { SetGenerateGlobalElementIdArray_4(id0); }

  private native int GetGenerateGlobalElementIdArray_5();
  public int GetGenerateGlobalElementIdArray()
    { return GetGenerateGlobalElementIdArray_5(); }

  private native void GenerateGlobalElementIdArrayOn_6();
  public void GenerateGlobalElementIdArrayOn()
    { GenerateGlobalElementIdArrayOn_6(); }

  private native void GenerateGlobalElementIdArrayOff_7();
  public void GenerateGlobalElementIdArrayOff()
    { GenerateGlobalElementIdArrayOff_7(); }

  private native String GetGlobalElementIdArrayName_8();
  public String GetGlobalElementIdArrayName()
    { return GetGlobalElementIdArrayName_8(); }

  private native void SetGenerateGlobalNodeIdArray_9(int id0);
  public void SetGenerateGlobalNodeIdArray(int id0)
    { SetGenerateGlobalNodeIdArray_9(id0); }

  private native int GetGenerateGlobalNodeIdArray_10();
  public int GetGenerateGlobalNodeIdArray()
    { return GetGenerateGlobalNodeIdArray_10(); }

  private native void GenerateGlobalNodeIdArrayOn_11();
  public void GenerateGlobalNodeIdArrayOn()
    { GenerateGlobalNodeIdArrayOn_11(); }

  private native void GenerateGlobalNodeIdArrayOff_12();
  public void GenerateGlobalNodeIdArrayOff()
    { GenerateGlobalNodeIdArrayOff_12(); }

  private native String GetGlobalNodeIdArrayName_13();
  public String GetGlobalNodeIdArrayName()
    { return GetGlobalNodeIdArrayName_13(); }

  private native void SetGenerateVertexWeightArrays_14(int id0);
  public void SetGenerateVertexWeightArrays(int id0)
    { SetGenerateVertexWeightArrays_14(id0); }

  private native int GetGenerateVertexWeightArrays_15();
  public int GetGenerateVertexWeightArrays()
    { return GetGenerateVertexWeightArrays_15(); }

  private native void GenerateVertexWeightArraysOn_16();
  public void GenerateVertexWeightArraysOn()
    { GenerateVertexWeightArraysOn_16(); }

  private native void GenerateVertexWeightArraysOff_17();
  public void GenerateVertexWeightArraysOff()
    { GenerateVertexWeightArraysOff_17(); }

  private native int GetNumberOfVertexWeights_18();
  public int GetNumberOfVertexWeights()
    { return GetNumberOfVertexWeights_18(); }

  private native String GetVertexWeightArrayName_19(int id0);
  public String GetVertexWeightArrayName(int id0)
    { return GetVertexWeightArrayName_19(id0); }

  private native void SetGenerateEdgeWeightArrays_20(int id0);
  public void SetGenerateEdgeWeightArrays(int id0)
    { SetGenerateEdgeWeightArrays_20(id0); }

  private native int GetGenerateEdgeWeightArrays_21();
  public int GetGenerateEdgeWeightArrays()
    { return GetGenerateEdgeWeightArrays_21(); }

  private native void GenerateEdgeWeightArraysOn_22();
  public void GenerateEdgeWeightArraysOn()
    { GenerateEdgeWeightArraysOn_22(); }

  private native void GenerateEdgeWeightArraysOff_23();
  public void GenerateEdgeWeightArraysOff()
    { GenerateEdgeWeightArraysOff_23(); }

  private native int GetNumberOfEdgeWeights_24();
  public int GetNumberOfEdgeWeights()
    { return GetNumberOfEdgeWeights_24(); }

  private native String GetEdgeWeightArrayName_25(int id0);
  public String GetEdgeWeightArrayName(int id0)
    { return GetEdgeWeightArrayName_25(id0); }

  private native int GetDimensionality_26();
  public int GetDimensionality()
    { return GetDimensionality_26(); }

  private native int GetNumberOfEdges_27();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_27(); }

  private native int GetNumberOfVertices_28();
  public int GetNumberOfVertices()
    { return GetNumberOfVertices_28(); }

  private native int GetNumberOfCellWeightArrays_29();
  public int GetNumberOfCellWeightArrays()
    { return GetNumberOfCellWeightArrays_29(); }

  private native int GetNumberOfPointWeightArrays_30();
  public int GetNumberOfPointWeightArrays()
    { return GetNumberOfPointWeightArrays_30(); }

  public vtkChacoReader() { super(); }

  public vtkChacoReader(long id) { super(id); }
  public native long   VTKInit();

}
